(*
  Copyright 2010 Gerd Stolpmann

  This file is part of Plasma, a distributed filesystem and a
  map/reduce computation framework. Unless you have a written license
  agreement with the copyright holder (Gerd Stolpmann), the following
  terms apply:

  Plasma is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  Plasma is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.

*)
(* $Id: mapred_config.ml 239 2010-06-23 16:49:03Z gerd $ *)

class type mapred_config =
object
  method nn_clustername : string
  method nn_nodes : string list
  method mr_task_nodes : string list
  method mr_task_port : int
  method mr_task_tmpdir : string
  method mr_task_load_limit : float
  method mr_shm_low : int64
  method mr_shm_high : int64
end


let extract_config cf =
  let namenodes =
    cf#resolve_section cf#root_addr "namenodes" in
  let nn = 
    match namenodes with
      | [] ->
          failwith "missing 'namenodes' config"
      | _ :: _ :: _ ->
          failwith "more than one 'namenodes' config"
      | [nn] ->
	  nn in
  
  let nn_addrs = Plasma_util.node_list cf nn in
  
  let clustername =
    try
      let p = cf#resolve_parameter nn "clustername" in
      cf#string_param p
    with
      | Not_found ->
          failwith "missing 'namenodes.clustername' parameter" in
  
  let mapreds =
    cf#resolve_section cf#root_addr "mapred" in

  let mr = 
    match mapreds with
      | [] ->
          failwith "missing 'mapred' config"
      | _ :: _ :: _ ->
          failwith "more than one 'mapred' config"
      | [mr] ->
	  mr in
  
  let mr_addrs = Plasma_util.node_list cf mr in
  let mr_hosts =
    List.map
      (fun s ->
	 fst (Plasma_util.parse_host_port s)
      )
      mr_addrs in
  if mr_hosts = [] then
    failwith "missing 'mapred.node' config";

  let mr_task_port =
    try
      let p = cf#resolve_parameter mr "port" in
      cf#int_param p
    with
      | Not_found ->
          failwith "missing 'mapred.port' parameter" in

  let mr_task_tmpdir =
    try
      let p = cf#resolve_parameter mr "tmpdir" in
      cf#string_param p
    with
      | Not_found ->
          failwith "missing 'mapred.tmpdir' parameter" in
  
  let mr_task_load_limit =
    try
      let p = cf#resolve_parameter mr "load_limit" in
      cf#float_param p
    with
      | Not_found ->
          failwith "missing 'mapred.load_limit' parameter" in

  let mr_shm_low =
    try
      let p = cf#resolve_parameter mr "shm_low" in
      try Int64.of_string (cf#string_param p)
      with _ -> Int64.of_int (cf#int_param p)
    with
      | Not_found ->
          failwith "missing 'mapred.shm_low' parameter" in

  let mr_shm_high =
    try
      let p = cf#resolve_parameter mr "shm_high" in
      try Int64.of_string (cf#string_param p)
      with _ -> Int64.of_int (cf#int_param p)
    with
      | Not_found ->
          failwith "missing 'mapred.shm_high' parameter" in


  ( object
      method nn_clustername = clustername
      method nn_nodes = nn_addrs
      method mr_task_nodes = mr_hosts
      method mr_task_port = mr_task_port
      method mr_task_tmpdir = mr_task_tmpdir
      method mr_task_load_limit = mr_task_load_limit
      method mr_shm_low = mr_shm_low
      method mr_shm_high = mr_shm_high
    end
  )

