(*
  Copyright 2010 Gerd Stolpmann

  This file is part of Plasma, a distributed filesystem and a
  map/reduce computation framework. Unless you have a written license
  agreement with the copyright holder (Gerd Stolpmann), the following
  terms apply:

  Plasma is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  Plasma is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.

*)
(* $Id: mapred_config.mli 239 2010-06-23 16:49:03Z gerd $ *)

(** Configuration of mapred servers *)

class type mapred_config =
object
  method nn_clustername : string
    (** The clustername *)
  method nn_nodes : string list
    (** The name nodes in "host:port" syntax *)
  method mr_task_nodes : string list
    (** Task nodes (only hostname) *)
  method mr_task_port : int
    (** The port number *)
  method mr_task_tmpdir : string
    (** A directory where to put executables, logs, etc. *)
  method mr_task_load_limit : float
    (** Load limit per task server (in number of tasks) *)
  method mr_shm_low : int64
    (** Low watermark for shared memory *)
  method mr_shm_high : int64
    (** High watermark for shared memory *)
end


val extract_config : Netplex_types.config_file -> mapred_config
  (** Config section must look like:

      {[
         netplex {
           ...
           namenodes {
             clustername = "cluster1";
             node { addr = "hostname:port" }
             node { addr = "hostname:port" }
             ...
           }
           mapred {
             node { addr = "hostname" }
             node { addr = "hostname" }
             ...
             port = 1234;
             tmpdir = "/somewhere";
             load_limit = 8.1;
           }
        }
      ]}
   *)
